{% load review_tags i18n %}
<table>
    {% for category, average_rating in category_averages.iteritems %}
        <tr>
            <th>{{ category.name }}:</th><td>{{ average_rating|floatformat:1 }}</td>
        </tr>
    {% endfor %}
    <tr>
        {% get_review_count reviewed_item as review_amount %}
        <th>{% trans "Amount of reviews" %}:</th><td>{{ review_amount }}</td>
    </tr>
</table>
